#
# spec file for package libidmef
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libidmef
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  pkg-config
Url:            http://sourceforge.net/projects/libidmef
Summary:        C Library for the Intrusion Detection Message Exchange Format (IDMEF)
License:        BSD-3-Clause and GPL-2.0+
Group:          Development/Libraries/C and C++
Version:        1.0.2
Release:        28.3
Source:         libidmef-%{version}.tar.gz
Patch1:         libidmef-%{version}_cleanup_autoconf.diff
Patch2:         libidmef-%{version}_parser_fatal_error_handling.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Libidmef is a C implementation of the "Intrusion Detection Message
Exchange Format" (IDMEF) made by Silicon Defense.


%define library_name libidmef1
%define debug_package_requires %{library_name} = %{version}-%{release}

%package -n libidmef1
Summary:        C Library for the "Intrusion Detection Message Exchange Format" (IDMEF)
Group:          Development/Libraries/C and C++

%description -n libidmef1
Libidmef is a C implementation of the "Intrusion Detection Message
Exchange Format" (IDMEF) made by Silicon Defense.


%package devel
Summary:        C Library for the "Intrusion Detection Message Exchange Format" (IDMEF)
Group:          Development/Libraries/C and C++
Requires:       %{library_name} = %{version}

%description devel
Libidmef is a C implementation of the "Intrusion Detection Message
Exchange Format" (IDMEF) made by Silicon Defense.



Authors:
--------
    Joe McAlerney, joey@silicondefense.com
    Adam Migus, NAI Labs, amigus@NAI.com

%prep
%setup -q
dos2unix ChangeLog
%patch1 -p1
%patch2 -p1

%build
%{?suse_update_config:%{suse_update_config -f .}}
cp libidmef-functions.map libidmef-functions-rfc.map
autoreconf -i -f
#LDFLAGS="$(xml2-config --libs)" \
#CFLAGS="$RPM_OPT_FLAGS $(xml2-config --cflags) -fno-strict-aliasing" \
%configure --disable-static --with-pic 
%{__make} %{?jobs:-j%jobs}

%install
# make directories
mkdir -p $RPM_BUILD_ROOT/etc/idmef/
mkdir -p $RPM_BUILD_ROOT/%{_libdir}
# install files
make DESTDIR=$RPM_BUILD_ROOT install
install xml/idmef-message.dtd $RPM_BUILD_ROOT/etc/idmef/
%{__rm} -f %{buildroot}%{_libdir}/*.la
#strip $RPM_BUILD_ROOT/%{_libdir}/libidmef.so.%{version}

%post   -n %{library_name} -p /sbin/ldconfig

%postun -n %{library_name} -p /sbin/ldconfig

%clean
rm -rf $RPM_BUILD_ROOT

%files -n %{library_name}
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog INSTALL NEWS README TODO
%attr(755,root,root) %dir /etc/idmef
%attr(755,root,root) %dir /usr/share/idmef-messages
%attr(644,root,root) %config /etc/idmef/idmef-message.dtd
%attr(555,root,root) %{_libdir}/libidmef.so.*

%files devel
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog INSTALL NEWS README TODO
%attr(755,root,root) %dir /usr/include/libidmef
%attr(755,root,root) %dir /etc/idmef
%attr(755,root,root) %dir /usr/share/idmef-messages
%attr(555,root,root) %{_libdir}/libidmef.so
#%attr(644,root,root) %config /etc/idmef/idmef-message.dtd
%attr(755,root,root) /usr/bin/libidmef-config
%attr(644,root,root) /usr/include/libidmef/idmef_create.h
%attr(644,root,root) /usr/include/libidmef/idmef_global.h
%attr(644,root,root) /usr/include/libidmef/idmef_list.h
%attr(644,root,root) /usr/include/libidmef/idmef_message.h
%attr(644,root,root) /usr/include/libidmef/idmef_parser.h
%attr(644,root,root) /usr/include/libidmef/idmef_parser_helpers.h
%attr(644,root,root) /usr/include/libidmef/idmef_strings.h
%attr(644,root,root) /usr/include/libidmef/idmef_types.h
%attr(644,root,root) %{_libdir}/pkgconfig/libidmef.pc
%attr(644,root,root) /usr/share/idmef-message.dtd
%attr(644,root,root) /usr/share/idmef-messages/example1.xml
%attr(644,root,root) /usr/share/idmef-messages/example10.xml
%attr(644,root,root) /usr/share/idmef-messages/example11.xml
%attr(644,root,root) /usr/share/idmef-messages/example12.xml
%attr(644,root,root) /usr/share/idmef-messages/example13.xml
%attr(644,root,root) /usr/share/idmef-messages/example14.xml
%attr(644,root,root) /usr/share/idmef-messages/example15.xml
%attr(644,root,root) /usr/share/idmef-messages/example16.xml
%attr(644,root,root) /usr/share/idmef-messages/example17.xml
%attr(644,root,root) /usr/share/idmef-messages/example18.xml
%attr(644,root,root) /usr/share/idmef-messages/example2.xml
%attr(644,root,root) /usr/share/idmef-messages/example20.xml
%attr(644,root,root) /usr/share/idmef-messages/example3.xml
%attr(644,root,root) /usr/share/idmef-messages/example4.xml
%attr(644,root,root) /usr/share/idmef-messages/example5.xml
%attr(644,root,root) /usr/share/idmef-messages/example6.xml
%attr(644,root,root) /usr/share/idmef-messages/example7.xml
%attr(644,root,root) /usr/share/idmef-messages/example8.xml
%attr(644,root,root) /usr/share/idmef-messages/example9.xml

%changelog
* Wed Mar  6 2013 coolo@suse.com
- update license to new format
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Wed Jun 22 2011 meissner@novell.com
- small fixes
* Thu Aug 27 2009 thomas@novell.com
- fixed more build problems
* Wed Aug 26 2009 thomas@novell.com
- changed BuildRequiers filed
* Thu Aug 13 2009 thomas@novell.com
- removed file libidmef-1.0.2-rpmlintrc
* Thu Aug 13 2009 thomas@novell.com
- fixed lib path for 64bit archs
* Wed Aug 12 2009 thomas@novell.com
- fixed build error (shlib-policy-name-error) caused by package
  name conventions
* Wed Aug 12 2009 thomas@novell.com
- fixed error handling in parser.c (removed exit(2) etc.)
* Tue Aug 11 2009 thomas@novell.com
- fixed compiling errors
* Thu Aug  6 2009 thomas@novell.com
- added rpmlint filter
* Wed Aug  5 2009 thomas@novell.com
- fixed build failures
* Mon Aug  3 2009 thomas@novell.com
- updated to version 1.0.2
  - fixed a segfault issue when a tag <IDMEF-Message> was given
    without attributes and idmefp should be generated
  - cleaned up code from commented out test code
  - fixed issues which could lead to segfaults (Thanks to Joel
    Winteregg for reporting)
  - idmef-messages.dtd updated to last draft
  - fixed missing checks for memory allocation errrors
  - fixed a missing return in get_checksum_algorithm()
  - added tty attribute to UserID which has been forgotten ;)
  - added newUserId_tty to libidmef-functions.map
  - fixed various segfault issues (NULL pointer dereference) in
    parser.c when debugging was enabled AND gen_idmefp was set to TRUE
  - added newToolAlert_analyzerid, newCorrelationAlert_analyzerid
  - changed newAnalyzer_id to newAnalyzer_analyzerid
* Fri Mar  6 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Thu Oct  9 2008 thomas@suse.de
- fixed build failures due to 02-check-gcc-output
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Oct 31 2005 dmueller@suse.de
- don't build as root
* Tue Apr 20 2004 thomas@suse.de
- removed cleanup commands from %%install section
* Tue Apr 20 2004 thomas@suse.de
- try to solve build-problem by using '-fno-strict-aliasing'
  (can not reproduce the problem)
* Mon Feb  2 2004 thomas@suse.de
- removed file conflict reported by PDB
* Fri Jan  9 2004 thomas@suse.de
- added patch from Marcus Meissner to solve libtool problem
* Tue Jan  6 2004 thomas@suse.de
- initial version
